@@ -10,7 +10,6 @@ import yaml
 import time
 import atexit
 import random
-from concurrent.futures import ThreadPoolExecutor
 
 from sycommon.config.Config import SingletonMeta
 from sycommon.logging.kafka_log import SYLogger
@@ -34,22 +33,17 @@ class NacosService(metaclass=SingletonMeta):
             # 添加可重入锁用于状态同步
             self._state_lock = threading.RLock()
 
-            # 优化线程池配置，增加工作线程数量
-            self._executor = ThreadPoolExecutor(max_workers=1)  # 主线程池
-            self._heartbeat_executor = ThreadPoolExecutor(
-                max_workers=1)  # 增加心跳线程
-            self._monitor_executor = ThreadPoolExecutor(
-                max_workers=1)  # 增加监控线程
-
             # 配置参数
             self.max_retries = self.nacos_config.get('maxRetries', 5)
             self.retry_delay = self.nacos_config.get('retryDelay', 1)
-            self.retry_backoff = self.nacos_config.get('retryBackoff', 1.5)
             self.max_retry_delay = self.nacos_config.get('maxRetryDelay', 30)
+            # 心跳间隔：优先从配置读取，默认15秒（可通过配置修改）
             self.heartbeat_interval = self.nacos_config.get(
                 'heartbeatInterval', 15)
+            # 心跳超时：固定设置为10秒（需求指定）
+            self.heartbeat_timeout = 15
             self.register_retry_interval = self.nacos_config.get(
-                'registerRetryInterval', 5)  # 注册重试间隔
+                'registerRetryInterval', 15)  # 注册重试间隔
 
             # 长期重试配置
             self.long_term_retry_delay = self.nacos_config.get(
@@ -129,8 +123,7 @@ class NacosService(metaclass=SingletonMeta):
                 self._client_initialized = True
                 return True
             except Exception as e:
-                delay = min(self.retry_delay * (self.retry_backoff **
-                            attempt), self.max_retry_delay)
+                delay = min(self.retry_delay, self.max_retry_delay)
                 SYLogger.error(
                     f"nacos:客户端初始化失败 (尝试 {attempt+1}/{self.max_retries}): {e}")
                 time.sleep(delay)
@@ -193,8 +186,7 @@ class NacosService(metaclass=SingletonMeta):
 
                 except Exception as e:
                     attempt += 1
-                    delay = min(self.retry_delay * (self.retry_backoff **
-                                (attempt - 1)), self.max_retry_delay)
+                    delay = min(self.retry_delay, self.max_retry_delay)
 
                     SYLogger.error(
                         f"nacos:客户端初始化失败 (尝试 {attempt}/{max_attempts}): {e}")
@@ -342,8 +334,7 @@ class NacosService(metaclass=SingletonMeta):
             except Exception as e:
                 last_error = str(e)
                 retry_count += 1
-                delay = min(self.register_retry_interval *
-                            (self.retry_backoff ** (retry_count - 1)), self.max_retry_delay)
+                delay = min(self.register_retry_interval, self.max_retry_delay)
 
                 SYLogger.warning(
                     f"nacos:服务注册尝试 {retry_count} 失败: {last_error}，{delay}秒后重试")
@@ -429,8 +420,13 @@ class NacosService(metaclass=SingletonMeta):
             timeout = 60  # 60秒超时
             start_time = time.time()
 
-            # 启动注册线程，不阻塞主线程
-            instance._executor.submit(instance.register_with_retry)
+            # 启动注册线程，不阻塞主线程（替换原线程池）
+            register_thread = threading.Thread(
+                target=instance.register_with_retry,
+                daemon=True,
+                name="NacosRegisterThread"
+            )
+            register_thread.start()
 
             # 等待注册完成或超时
             while True:
@@ -461,7 +457,7 @@ class NacosService(metaclass=SingletonMeta):
 
             # 启动连接监控线程
             threading.Thread(target=instance.monitor_connection,
-                             daemon=True).start()
+                             daemon=True, name="NacosConnectionMonitorThread").start()
         else:
             SYLogger.info("nacos:本地开发模式，跳过服务注册流程")
 
@@ -485,7 +481,11 @@ class NacosService(metaclass=SingletonMeta):
             )
             self._heartbeat_thread.daemon = True
             self._heartbeat_thread.start()
-            SYLogger.info(f"nacos:心跳线程启动，线程ID: {self._heartbeat_thread.ident}")
+            SYLogger.info(
+                f"nacos:心跳线程启动，线程ID: {self._heartbeat_thread.ident}，"
+                f"心跳间隔: {self.heartbeat_interval}秒，"
+                f"心跳超时: {self.heartbeat_timeout}秒"
+            )
 
     def _send_heartbeat_loop(self):
         """优化后的心跳发送循环，确保严格按间隔执行"""
@@ -493,7 +493,8 @@ class NacosService(metaclass=SingletonMeta):
         thread_ident = current_thread.ident
         SYLogger.info(
             f"nacos:心跳循环启动 - 线程ID: {thread_ident}, "
-            f"配置间隔: {self.heartbeat_interval}秒"
+            f"配置间隔: {self.heartbeat_interval}秒, "
+            f"超时时间: {self.heartbeat_timeout}秒"
         )
 
         consecutive_fail = 0  # 连续失败计数器
@@ -512,7 +513,7 @@ class NacosService(metaclass=SingletonMeta):
                         f"nacos:服务未注册，跳过心跳 - 线程ID: {thread_ident}")
                     consecutive_fail = 0
                 else:
-                    # 发送心跳
+                    # 发送心跳（10秒超时）
                     success = self.send_heartbeat()
                     if success:
                         consecutive_fail = 0
@@ -545,26 +546,46 @@ class NacosService(metaclass=SingletonMeta):
         SYLogger.info(f"nacos:心跳循环已停止 - 线程ID: {thread_ident}")
 
     def send_heartbeat(self):
-        """发送心跳并添加超时控制"""
+        """发送心跳并添加10秒超时控制（替换线程池实现）"""
         if not self.ensure_client_connected():
             SYLogger.warning("nacos:客户端未连接，心跳发送失败")
             return False
 
-        try:
-            # 严格控制心跳超时（3秒）
-            future = self._heartbeat_executor.submit(
-                self._send_heartbeat_internal)
-            result = future.result(timeout=3)  # 超时后抛出异常
+        # 用线程+join实现10秒超时控制
+        result_list = []  # 用于线程间传递结果
 
-            if result:
-                # 只有确认成功才更新时间戳
-                self._last_successful_heartbeat = time.time()
-            return result
-        except Exception as e:
-            SYLogger.error(f"nacos:发送心跳时发生异常: {e}")
+        def heartbeat_task():
+            """心跳实际执行任务"""
+            try:
+                result = self._send_heartbeat_internal()
+                result_list.append(result)
+            except Exception as e:
+                SYLogger.error(f"nacos:心跳任务执行异常: {e}")
+                result_list.append(False)
+
+        # 启动心跳任务线程
+        task_thread = threading.Thread(
+            target=heartbeat_task,
+            daemon=True,
+            name="NacosHeartbeatTaskThread"
+        )
+        task_thread.start()
+
+        # 等待线程完成，最多等待10秒
+        task_thread.join(timeout=self.heartbeat_timeout)
+
+        # 处理结果
+        if not result_list:
+            # 超时未返回
+            SYLogger.error(f"nacos:心跳发送超时（{self.heartbeat_timeout}秒）")
             self._client_initialized = False  # 强制重连
             return False
 
+        # 检查心跳结果
+        if result_list[0]:
+            self._last_successful_heartbeat = time.time()
+        return result_list[0]
+
     def _send_heartbeat_internal(self):
         """实际的心跳发送逻辑"""
         result = self.nacos_client.send_heartbeat(
@@ -620,9 +641,13 @@ class NacosService(metaclass=SingletonMeta):
                         else:
                             self.registered = False
                             SYLogger.warning(f"nacos:服务实例未注册，尝试重新注册")
-                            # 不在锁内调用可能耗时的操作
-                            self._monitor_executor.submit(
-                                self.register_with_retry)
+                            # 启动临时线程执行重新注册（替换原线程池）
+                            retry_thread = threading.Thread(
+                                target=self.register_with_retry,
+                                daemon=True,
+                                name="NacosRetryRegisterThread"
+                            )
+                            retry_thread.start()
 
                 # 20%的概率执行深度检查
                 if random.random() < 0.2:
@@ -673,13 +698,6 @@ class NacosService(metaclass=SingletonMeta):
             SYLogger.error(f"nacos:注销服务时发生错误: {e}")
         finally:
             self._shutdown_event.set()
-            # 优雅地关闭线程池
-            if self._executor and not self._executor._shutdown:
-                self._executor.shutdown(wait=True)
-            if self._heartbeat_executor and not self._heartbeat_executor._shutdown:
-                self._heartbeat_executor.shutdown(wait=True)
-            if self._monitor_executor and not self._monitor_executor._shutdown:
-                self._monitor_executor.shutdown(wait=True)
 
     def handle_signal(self, signum, frame):
         """处理退出信号"""
@@ -751,7 +769,8 @@ class NacosService(metaclass=SingletonMeta):
                 for data_id, callback in list(self._config_listeners.items()):
                     new_config = self.get_config(data_id)
                     if new_config and new_config != self._config_cache.get(data_id):
-                        self._executor.submit(callback, new_config)
+                        # 直接执行回调（替换原线程池，配置回调通常为轻量操作）
+                        callback(new_config)
                         self._config_cache[data_id] = new_config
             except Exception as e:
                 SYLogger.error(f"nacos:配置监视线程异常: {str(e)}")
